@@ -28,7 +28,7 @@
 #'
 #' tidy(geefit)
 #' tidy(geefit, conf.int = TRUE)
-#' @evalRd return_tidy(regresion = TRUE)
+#' @evalRd return_tidy(regression = TRUE)
 #'
 #' @export
 #' @aliases geeglm_tidiers geepack_tidiers
@@ -42,36 +42,25 @@ tidy.geeglm <- function(x, conf.int = FALSE, conf.level = .95,
     co, 
     c("estimate", "std.error", "statistic", "p.value")[1:ncol(co)]
   )
-
-  process_geeglm(ret, x,
-    conf.int = conf.int, conf.level = conf.level,
-    exponentiate = exponentiate
-  )
-}
-
-process_geeglm <- function(ret, x, conf.int = FALSE, conf.level = .95,
-                           exponentiate = FALSE) {
+  
+  if (conf.int) {
+    ci <- broom_confint_terms(x, level = conf.level)
+    ret <- dplyr::left_join(ret, ci, by = "term")
+  }
+  
   if (exponentiate) {
-    # save transformation function for use on confidence interval
     if (is.null(x$family) ||
-      (x$family$link != "logit" && x$family$link != "log")) {
+        (x$family$link != "logit" && x$family$link != "log")) {
       warning(paste(
         "Exponentiating coefficients, but model did not use",
         "a log or logit link function"
       ))
     }
-    trans <- exp
-  } else {
-    trans <- identity
+    
+    ret <- exponentiate(ret)
   }
-
-  if (conf.int) {
-    ci <- broom_confint_terms(x, level = conf.level)
-    ret <- dplyr::left_join(ret, ci, by = "term")
-  }
-  ret$estimate <- trans(ret$estimate)
-
-  as_tibble(ret)
+  
+  ret
 }
 
 #' Generate confidence intervals for geeglm objects
@@ -83,7 +72,7 @@ process_geeglm <- function(ret, x, conf.int = FALSE, conf.level = .95,
 #' @param level Confidence level of the interval.
 #' @param ... Additional parameters (ignored).
 #'
-#' @details From http://stackoverflow.com/a/21221995/2632184.
+#' @details From https://stackoverflow.com/a/21221995/2632184.
 #'
 #' @return Lower and upper confidence bounds in a data.frame(?).
 #'
